Class: AsposeSlidesCloud::CaptionTrack
- Inherits:
-
ResourceBase
- Object
- BaseObject
- ResourceBase
- AsposeSlidesCloud::CaptionTrack
- Defined in:
- lib/aspose_slides_cloud/models/caption_track.rb
Overview
Represents list of Links to Paragraphs resources
Instance Attribute Summary collapse
-
#caption_id ⇒ Object
Caption ID.
-
#data_as_string ⇒ Object
Caption track data as string.
-
#label ⇒ Object
Label.
Attributes inherited from ResourceBase
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CaptionTrack
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from BaseObject
#_deserialize, #_to_hash, #build_from_hash, #to_body, #to_hash, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CaptionTrack
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/aspose_slides_cloud/models/caption_track.rb', line 57 def initialize(attributes = {}) super if attributes.has_key?(:'CaptionId') self.caption_id = attributes[:'CaptionId'] end if attributes.has_key?(:'Label') self.label = attributes[:'Label'] end if attributes.has_key?(:'DataAsString') self.data_as_string = attributes[:'DataAsString'] end end |
Instance Attribute Details
#caption_id ⇒ Object
Caption ID.
29 30 31 |
# File 'lib/aspose_slides_cloud/models/caption_track.rb', line 29 def caption_id @caption_id end |
#data_as_string ⇒ Object
Caption track data as string.
35 36 37 |
# File 'lib/aspose_slides_cloud/models/caption_track.rb', line 35 def data_as_string @data_as_string end |
#label ⇒ Object
Label.
32 33 34 |
# File 'lib/aspose_slides_cloud/models/caption_track.rb', line 32 def label @label end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 |
# File 'lib/aspose_slides_cloud/models/caption_track.rb', line 38 def self.attribute_map super.merge({ :'caption_id' => :'CaptionId', :'label' => :'Label', :'data_as_string' => :'DataAsString', }) end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/aspose_slides_cloud/models/caption_track.rb', line 47 def self.swagger_types super.merge({ :'caption_id' => :'String', :'label' => :'String', :'data_as_string' => :'String', }) end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
94 95 96 97 98 99 100 101 102 |
# File 'lib/aspose_slides_cloud/models/caption_track.rb', line 94 def ==(o) return true if self.equal?(o) self.class == o.class && self_uri == o.self_uri && alternate_links == o.alternate_links && caption_id == o.caption_id && label == o.label && data_as_string == o.data_as_string end |
#eql?(o) ⇒ Boolean
106 107 108 |
# File 'lib/aspose_slides_cloud/models/caption_track.rb', line 106 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
112 113 114 |
# File 'lib/aspose_slides_cloud/models/caption_track.rb', line 112 def hash [self_uri, alternate_links, caption_id, label, data_as_string].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
75 76 77 78 79 80 81 82 |
# File 'lib/aspose_slides_cloud/models/caption_track.rb', line 75 def list_invalid_properties invalid_properties = super if @caption_id.nil? invalid_properties.push('invalid value for "caption_id", caption_id cannot be nil.') end invalid_properties end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
86 87 88 89 90 |
# File 'lib/aspose_slides_cloud/models/caption_track.rb', line 86 def valid? return false if !super return false if @caption_id.nil? true end |