Class: AsposeSlidesCloud::Html5ExportOptions

Inherits:
ExportOptions show all
Defined in:
lib/aspose_slides_cloud/models/html5_export_options.rb

Overview

Provides options that control how a presentation is saved in Html5 format.

Instance Attribute Summary collapse

Attributes inherited from ExportOptions

#default_regular_font, #delete_embedded_binary_objects, #font_fallback_rules, #font_subst_rules, #format, #gradient_style, #skip_java_script_links

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseObject

#_deserialize, #_to_hash, #build_from_hash, #to_body, #to_hash, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Html5ExportOptions

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 72

def initialize(attributes = {})
  super

  if attributes.has_key?(:'AnimateTransitions')
    self.animate_transitions = attributes[:'AnimateTransitions']
  end

  if attributes.has_key?(:'AnimateShapes')
    self.animate_shapes = attributes[:'AnimateShapes']
  end

  if attributes.has_key?(:'EmbedImages')
    self.embed_images = attributes[:'EmbedImages']
  end

  if attributes.has_key?(:'SlidesLayoutOptions')
    self.slides_layout_options = attributes[:'SlidesLayoutOptions']
  end

  if attributes.has_key?(:'TemplatesPath')
    self.templates_path = attributes[:'TemplatesPath']
  end

  if attributes.has_key?(:'DisableFontLigatures')
    self.disable_font_ligatures = attributes[:'DisableFontLigatures']
  end
  self.format = 'html5'
end

Instance Attribute Details

#animate_shapesObject

Gets or sets shapes animation option.



32
33
34
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 32

def animate_shapes
  @animate_shapes
end

#animate_transitionsObject

Gets or sets transitions animation option.



29
30
31
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 29

def animate_transitions
  @animate_transitions
end

#disable_font_ligaturesObject

true to disable ligatures in the rendered output.



44
45
46
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 44

def disable_font_ligatures
  @disable_font_ligatures
end

#embed_imagesObject

Gets or sets embed images option.



35
36
37
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 35

def embed_images
  @embed_images
end

#slides_layout_optionsObject

Slides layouting options



38
39
40
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 38

def slides_layout_options
  @slides_layout_options
end

#templates_pathObject

Path to custom templates



41
42
43
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 41

def templates_path
  @templates_path
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 47

def self.attribute_map
  super.merge({
    :'animate_transitions' => :'AnimateTransitions',
    :'animate_shapes' => :'AnimateShapes',
    :'embed_images' => :'EmbedImages',
    :'slides_layout_options' => :'SlidesLayoutOptions',
    :'templates_path' => :'TemplatesPath',
    :'disable_font_ligatures' => :'DisableFontLigatures',
  })
end

.swagger_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 59

def self.swagger_types
  super.merge({
    :'animate_transitions' => :'BOOLEAN',
    :'animate_shapes' => :'BOOLEAN',
    :'embed_images' => :'BOOLEAN',
    :'slides_layout_options' => :'SlidesLayoutOptions',
    :'templates_path' => :'String',
    :'disable_font_ligatures' => :'BOOLEAN',
  })
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 117

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      default_regular_font == o.default_regular_font &&
      delete_embedded_binary_objects == o.delete_embedded_binary_objects &&
      gradient_style == o.gradient_style &&
      font_fallback_rules == o.font_fallback_rules &&
      font_subst_rules == o.font_subst_rules &&
      skip_java_script_links == o.skip_java_script_links &&
      format == o.format &&
      animate_transitions == o.animate_transitions &&
      animate_shapes == o.animate_shapes &&
      embed_images == o.embed_images &&
      slides_layout_options == o.slides_layout_options &&
      templates_path == o.templates_path &&
      disable_font_ligatures == o.disable_font_ligatures
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


137
138
139
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 137

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



143
144
145
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 143

def hash
  [default_regular_font, delete_embedded_binary_objects, gradient_style, font_fallback_rules, font_subst_rules, skip_java_script_links, format, animate_transitions, animate_shapes, embed_images, slides_layout_options, templates_path, disable_font_ligatures].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



103
104
105
106
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 103

def list_invalid_properties
  invalid_properties = super
  invalid_properties
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



110
111
112
113
# File 'lib/aspose_slides_cloud/models/html5_export_options.rb', line 110

def valid?
  return false if !super
  true
end