Class: AsposeSlidesCloud::MarkdownExportOptions

Inherits:
ExportOptions show all
Defined in:
lib/aspose_slides_cloud/models/markdown_export_options.rb

Overview

Provides options that control how a presentation is saved in Html5 format.

Instance Attribute Summary collapse

Attributes inherited from ExportOptions

#default_regular_font, #delete_embedded_binary_objects, #font_fallback_rules, #font_subst_rules, #format, #gradient_style, #skip_java_script_links

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseObject

#_deserialize, #_to_hash, #build_from_hash, #to_body, #to_hash, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MarkdownExportOptions

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 92

def initialize(attributes = {})
  super

  if attributes.has_key?(:'ExportType')
    self.export_type = attributes[:'ExportType']
  end

  if attributes.has_key?(:'Flavor')
    self.flavor = attributes[:'Flavor']
  end

  if attributes.has_key?(:'NewLineType')
    self.new_line_type = attributes[:'NewLineType']
  end

  if attributes.has_key?(:'ImagesSaveFolderName')
    self.images_save_folder_name = attributes[:'ImagesSaveFolderName']
  end

  if attributes.has_key?(:'ShowSlideNumber')
    self.show_slide_number = attributes[:'ShowSlideNumber']
  end

  if attributes.has_key?(:'ShowComments')
    self.show_comments = attributes[:'ShowComments']
  end

  if attributes.has_key?(:'ShowHiddenSlides')
    self.show_hidden_slides = attributes[:'ShowHiddenSlides']
  end

  if attributes.has_key?(:'RemoveEmptyLines')
    self.remove_empty_lines = attributes[:'RemoveEmptyLines']
  end

  if attributes.has_key?(:'HandleRepeatedSpaces')
    self.handle_repeated_spaces = attributes[:'HandleRepeatedSpaces']
  end

  if attributes.has_key?(:'SlideNumberFormat')
    self.slide_number_format = attributes[:'SlideNumberFormat']
  end
  self.format = 'md'
end

Instance Attribute Details

#export_typeObject

Specifies markdown specification to convert presentation. Default is TextOnly.



29
30
31
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 29

def export_type
  @export_type
end

#flavorObject

Specifies markdown specification to convert presentation. Default is MultiMarkdown.



32
33
34
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 32

def flavor
  @flavor
end

#handle_repeated_spacesObject

Specifies how repeated space characters are preserved to maintain visual alignment.



53
54
55
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 53

def handle_repeated_spaces
  @handle_repeated_spaces
end

#images_save_folder_nameObject

Specifies folder name to save images. Default is Images.



38
39
40
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 38

def images_save_folder_name
  @images_save_folder_name
end

#new_line_typeObject

Specifies whether the generated document should have new lines of \\r(Macintosh), \\n(Unix) or \\r\\n(Windows). Default is Unix.



35
36
37
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 35

def new_line_type
  @new_line_type
end

#remove_empty_linesObject

true to remove empty or whitespace-only lines from the final Markdown output. Default is false.



50
51
52
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 50

def remove_empty_lines
  @remove_empty_lines
end

#show_commentsObject

Specifies whether the generated document should include comments. Default is false.



44
45
46
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 44

def show_comments
  @show_comments
end

#show_hidden_slidesObject

Specifies whether the generated document should include hidden slides. Default is false.



47
48
49
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 47

def show_hidden_slides
  @show_hidden_slides
end

#show_slide_numberObject

Specifies whether the generated document should include slide number. Default is false.



41
42
43
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 41

def show_slide_number
  @show_slide_number
end

#slide_number_formatObject

The format of slide number headers.



56
57
58
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 56

def slide_number_format
  @slide_number_format
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 59

def self.attribute_map
  super.merge({
    :'export_type' => :'ExportType',
    :'flavor' => :'Flavor',
    :'new_line_type' => :'NewLineType',
    :'images_save_folder_name' => :'ImagesSaveFolderName',
    :'show_slide_number' => :'ShowSlideNumber',
    :'show_comments' => :'ShowComments',
    :'show_hidden_slides' => :'ShowHiddenSlides',
    :'remove_empty_lines' => :'RemoveEmptyLines',
    :'handle_repeated_spaces' => :'HandleRepeatedSpaces',
    :'slide_number_format' => :'SlideNumberFormat',
  })
end

.swagger_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 75

def self.swagger_types
  super.merge({
    :'export_type' => :'String',
    :'flavor' => :'String',
    :'new_line_type' => :'String',
    :'images_save_folder_name' => :'String',
    :'show_slide_number' => :'BOOLEAN',
    :'show_comments' => :'BOOLEAN',
    :'show_hidden_slides' => :'BOOLEAN',
    :'remove_empty_lines' => :'BOOLEAN',
    :'handle_repeated_spaces' => :'String',
    :'slide_number_format' => :'String',
  })
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 201

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      default_regular_font == o.default_regular_font &&
      delete_embedded_binary_objects == o.delete_embedded_binary_objects &&
      gradient_style == o.gradient_style &&
      font_fallback_rules == o.font_fallback_rules &&
      font_subst_rules == o.font_subst_rules &&
      skip_java_script_links == o.skip_java_script_links &&
      format == o.format &&
      export_type == o.export_type &&
      flavor == o.flavor &&
      new_line_type == o.new_line_type &&
      images_save_folder_name == o.images_save_folder_name &&
      show_slide_number == o.show_slide_number &&
      show_comments == o.show_comments &&
      show_hidden_slides == o.show_hidden_slides &&
      remove_empty_lines == o.remove_empty_lines &&
      handle_repeated_spaces == o.handle_repeated_spaces &&
      slide_number_format == o.slide_number_format
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 225

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



231
232
233
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 231

def hash
  [default_regular_font, delete_embedded_binary_objects, gradient_style, font_fallback_rules, font_subst_rules, skip_java_script_links, format, export_type, flavor, new_line_type, images_save_folder_name, show_slide_number, show_comments, show_hidden_slides, remove_empty_lines, handle_repeated_spaces, slide_number_format].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



139
140
141
142
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 139

def list_invalid_properties
  invalid_properties = super
  invalid_properties
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/aspose_slides_cloud/models/markdown_export_options.rb', line 146

def valid?
  return false if !super
  export_type_validator = EnumAttributeValidator.new('String', ['Sequential', 'TextOnly', 'Visual'])
  return false unless export_type_validator.valid?(@export_type)
  flavor_validator = EnumAttributeValidator.new('String', ['Github', 'Gruber', 'MultiMarkdown', 'CommonMark', 'MarkdownExtra', 'Pandoc', 'Kramdown', 'Markua', 'Maruku', 'Markdown2', 'Remarkable', 'Showdown', 'Ghost', 'GitLab', 'Haroopad', 'IaWriter', 'Redcarpet', 'ScholarlyMarkdown', 'Taiga', 'Trello', 'S9ETextFormatter', 'XWiki', 'StackOverflow', 'Default'])
  return false unless flavor_validator.valid?(@flavor)
  new_line_type_validator = EnumAttributeValidator.new('String', ['Windows', 'Unix', 'Mac'])
  return false unless new_line_type_validator.valid?(@new_line_type)
  handle_repeated_spaces_validator = EnumAttributeValidator.new('String', ['None', 'AlternateSpacesToNbsp', 'MultipleSpacesToNbsp'])
  return false unless handle_repeated_spaces_validator.valid?(@handle_repeated_spaces)
  true
end