Class: AsposeSlidesCloud::PictureFill

Inherits:
FillFormat show all
Defined in:
lib/aspose_slides_cloud/models/picture_fill.rb

Overview

Picture fill.

Instance Attribute Summary collapse

Attributes inherited from FillFormat

#type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseObject

#_deserialize, #_to_hash, #build_from_hash, #to_body, #to_hash, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PictureFill

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 132

def initialize(attributes = {})
  super

  if attributes.has_key?(:'CropBottom')
    self.crop_bottom = attributes[:'CropBottom']
  end

  if attributes.has_key?(:'CropLeft')
    self.crop_left = attributes[:'CropLeft']
  end

  if attributes.has_key?(:'CropRight')
    self.crop_right = attributes[:'CropRight']
  end

  if attributes.has_key?(:'CropTop')
    self.crop_top = attributes[:'CropTop']
  end

  if attributes.has_key?(:'Dpi')
    self.dpi = attributes[:'Dpi']
  end

  if attributes.has_key?(:'TileOffsetX')
    self.tile_offset_x = attributes[:'TileOffsetX']
  end

  if attributes.has_key?(:'TileOffsetY')
    self.tile_offset_y = attributes[:'TileOffsetY']
  end

  if attributes.has_key?(:'TileScaleX')
    self.tile_scale_x = attributes[:'TileScaleX']
  end

  if attributes.has_key?(:'TileScaleY')
    self.tile_scale_y = attributes[:'TileScaleY']
  end

  if attributes.has_key?(:'TileAlignment')
    self.tile_alignment = attributes[:'TileAlignment']
  end

  if attributes.has_key?(:'TileFlip')
    self.tile_flip = attributes[:'TileFlip']
  end

  if attributes.has_key?(:'Image')
    self.image = attributes[:'Image']
  end

  if attributes.has_key?(:'Base64Data')
    self.base64_data = attributes[:'Base64Data']
  end

  if attributes.has_key?(:'SvgData')
    self.svg_data = attributes[:'SvgData']
  end

  if attributes.has_key?(:'DeletePictureCroppedAreas')
    self.delete_picture_cropped_areas = attributes[:'DeletePictureCroppedAreas']
  end

  if attributes.has_key?(:'Resolution')
    self.resolution = attributes[:'Resolution']
  end

  if attributes.has_key?(:'PictureFillMode')
    self.picture_fill_mode = attributes[:'PictureFillMode']
  end

  if attributes.has_key?(:'ImageTransformList')
    if (value = attributes[:'ImageTransformList']).is_a?(Array)
      self.image_transform_list = value
    end
  end
  self.type = 'Picture'
end

Instance Attribute Details

#base64_dataObject

Base 64 image data.



65
66
67
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 65

def base64_data
  @base64_data
end

#crop_bottomObject

Percentage of image height that is cropped from the bottom.



29
30
31
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 29

def crop_bottom
  @crop_bottom
end

#crop_leftObject

Percentage of image height that is cropped from the left.



32
33
34
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 32

def crop_left
  @crop_left
end

#crop_rightObject

Percentage of image height that is cropped from the right.



35
36
37
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 35

def crop_right
  @crop_right
end

#crop_topObject

Percentage of image height that is cropped from the top.



38
39
40
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 38

def crop_top
  @crop_top
end

#delete_picture_cropped_areasObject

true to delete picture cropped areas on save.



71
72
73
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 71

def delete_picture_cropped_areas
  @delete_picture_cropped_areas
end

#dpiObject

Picture resolution.



41
42
43
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 41

def dpi
  @dpi
end

#imageObject

Internal image link.



62
63
64
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 62

def image
  @image
end

#image_transform_listObject

Image transform effects.



80
81
82
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 80

def image_transform_list
  @image_transform_list
end

#picture_fill_modeObject

Fill mode.



77
78
79
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 77

def picture_fill_mode
  @picture_fill_mode
end

#resolutionObject

true to compress the picture image with the specified resolution (in dpi) on save.



74
75
76
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 74

def resolution
  @resolution
end

#svg_dataObject

SVG image data.



68
69
70
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 68

def svg_data
  @svg_data
end

#tile_alignmentObject

The way texture is aligned within the shape. This setting controls the starting point of the texture pattern and how it repeats across the shape.



56
57
58
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 56

def tile_alignment
  @tile_alignment
end

#tile_flipObject

Flips the texture tile around its horizontal, vertical or both axis.



59
60
61
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 59

def tile_flip
  @tile_flip
end

#tile_offset_xObject

The horizontal offset of the texture from the shape’s origin in points. A positive value moves the texture to the right, while a negative value moves it to the left.



44
45
46
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 44

def tile_offset_x
  @tile_offset_x
end

#tile_offset_yObject

The vertical offset of the texture from the shape’s origin in points. A positive value moves the texture down, while a negative value moves it up.



47
48
49
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 47

def tile_offset_y
  @tile_offset_y
end

#tile_scale_xObject

The horizontal scale for the texture fill as a percentage.



50
51
52
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 50

def tile_scale_x
  @tile_scale_x
end

#tile_scale_yObject

The vertical scale for the texture fill as a percentage.



53
54
55
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 53

def tile_scale_y
  @tile_scale_y
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 83

def self.attribute_map
  super.merge({
    :'crop_bottom' => :'CropBottom',
    :'crop_left' => :'CropLeft',
    :'crop_right' => :'CropRight',
    :'crop_top' => :'CropTop',
    :'dpi' => :'Dpi',
    :'tile_offset_x' => :'TileOffsetX',
    :'tile_offset_y' => :'TileOffsetY',
    :'tile_scale_x' => :'TileScaleX',
    :'tile_scale_y' => :'TileScaleY',
    :'tile_alignment' => :'TileAlignment',
    :'tile_flip' => :'TileFlip',
    :'image' => :'Image',
    :'base64_data' => :'Base64Data',
    :'svg_data' => :'SvgData',
    :'delete_picture_cropped_areas' => :'DeletePictureCroppedAreas',
    :'resolution' => :'Resolution',
    :'picture_fill_mode' => :'PictureFillMode',
    :'image_transform_list' => :'ImageTransformList',
  })
end

.swagger_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 107

def self.swagger_types
  super.merge({
    :'crop_bottom' => :'Float',
    :'crop_left' => :'Float',
    :'crop_right' => :'Float',
    :'crop_top' => :'Float',
    :'dpi' => :'Integer',
    :'tile_offset_x' => :'Float',
    :'tile_offset_y' => :'Float',
    :'tile_scale_x' => :'Float',
    :'tile_scale_y' => :'Float',
    :'tile_alignment' => :'String',
    :'tile_flip' => :'String',
    :'image' => :'ResourceUri',
    :'base64_data' => :'String',
    :'svg_data' => :'String',
    :'delete_picture_cropped_areas' => :'BOOLEAN',
    :'resolution' => :'Float',
    :'picture_fill_mode' => :'String',
    :'image_transform_list' => :'Array<ImageTransformEffect>',
  })
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 293

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      crop_bottom == o.crop_bottom &&
      crop_left == o.crop_left &&
      crop_right == o.crop_right &&
      crop_top == o.crop_top &&
      dpi == o.dpi &&
      tile_offset_x == o.tile_offset_x &&
      tile_offset_y == o.tile_offset_y &&
      tile_scale_x == o.tile_scale_x &&
      tile_scale_y == o.tile_scale_y &&
      tile_alignment == o.tile_alignment &&
      tile_flip == o.tile_flip &&
      image == o.image &&
      base64_data == o.base64_data &&
      svg_data == o.svg_data &&
      delete_picture_cropped_areas == o.delete_picture_cropped_areas &&
      resolution == o.resolution &&
      picture_fill_mode == o.picture_fill_mode &&
      image_transform_list == o.image_transform_list
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


319
320
321
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 319

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



325
326
327
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 325

def hash
  [type, crop_bottom, crop_left, crop_right, crop_top, dpi, tile_offset_x, tile_offset_y, tile_scale_x, tile_scale_y, tile_alignment, tile_flip, image, base64_data, svg_data, delete_picture_cropped_areas, resolution, picture_fill_mode, image_transform_list].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 213

def list_invalid_properties
  invalid_properties = super
  if @crop_bottom.nil?
    invalid_properties.push('invalid value for "crop_bottom", crop_bottom cannot be nil.')
  end

  if @crop_left.nil?
    invalid_properties.push('invalid value for "crop_left", crop_left cannot be nil.')
  end

  if @crop_right.nil?
    invalid_properties.push('invalid value for "crop_right", crop_right cannot be nil.')
  end

  if @crop_top.nil?
    invalid_properties.push('invalid value for "crop_top", crop_top cannot be nil.')
  end

  if @dpi.nil?
    invalid_properties.push('invalid value for "dpi", dpi cannot be nil.')
  end

  if @picture_fill_mode.nil?
    invalid_properties.push('invalid value for "picture_fill_mode", picture_fill_mode cannot be nil.')
  end

  invalid_properties
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aspose_slides_cloud/models/picture_fill.rb', line 244

def valid?
  return false if !super
  return false if @crop_bottom.nil?
  return false if @crop_left.nil?
  return false if @crop_right.nil?
  return false if @crop_top.nil?
  return false if @dpi.nil?
  tile_alignment_validator = EnumAttributeValidator.new('String', ['TopLeft', 'Top', 'TopRight', 'Left', 'Center', 'Right', 'BottomLeft', 'Bottom', 'BottomRight', 'NotDefined'])
  return false unless tile_alignment_validator.valid?(@tile_alignment)
  tile_flip_validator = EnumAttributeValidator.new('String', ['NoFlip', 'FlipX', 'FlipY', 'FlipBoth', 'NotDefined'])
  return false unless tile_flip_validator.valid?(@tile_flip)
  return false if @picture_fill_mode.nil?
  picture_fill_mode_validator = EnumAttributeValidator.new('String', ['Tile', 'Stretch'])
  return false unless picture_fill_mode_validator.valid?(@picture_fill_mode)
  true
end