Class: AsposeSlidesCloud::PptxExportOptions

Inherits:
ExportOptions show all
Defined in:
lib/aspose_slides_cloud/models/pptx_export_options.rb

Overview

Provides options that control how a presentation is saved in PPTX format.

Instance Attribute Summary collapse

Attributes inherited from ExportOptions

#default_regular_font, #delete_embedded_binary_objects, #font_fallback_rules, #font_subst_rules, #format, #gradient_style, #skip_java_script_links

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseObject

#_deserialize, #_to_hash, #build_from_hash, #to_body, #to_hash, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PptxExportOptions

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 62

def initialize(attributes = {})
  super

  if attributes.has_key?(:'Conformance')
    self.conformance = attributes[:'Conformance']
  end

  if attributes.has_key?(:'Zip64Mode')
    self.zip64_mode = attributes[:'Zip64Mode']
  end

  if attributes.has_key?(:'CompressionLevel')
    self.compression_level = attributes[:'CompressionLevel']
  end

  if attributes.has_key?(:'RefreshThumbnail')
    self.refresh_thumbnail = attributes[:'RefreshThumbnail']
  end
  self.format = 'pptx'
end

Instance Attribute Details

#compression_levelObject

The compression level used when saving the presentation document. Higher compression levels produce smaller files but require more processing time. The actual compression ratio depends on the content of the presentation. The default value is CompressionLevel.Level6.



35
36
37
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 35

def compression_level
  @compression_level
end

#conformanceObject

The conformance class to which the PresentationML document conforms.



29
30
31
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 29

def conformance
  @conformance
end

#refresh_thumbnailObject

True to refresh the presentation thumbnail on save



38
39
40
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 38

def refresh_thumbnail
  @refresh_thumbnail
end

#zip64_modeObject

Specifies whether the ZIP64 format is used for the Presentation document. The default value is Zip64Mode.IfNecessary.



32
33
34
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 32

def zip64_mode
  @zip64_mode
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 41

def self.attribute_map
  super.merge({
    :'conformance' => :'Conformance',
    :'zip64_mode' => :'Zip64Mode',
    :'compression_level' => :'CompressionLevel',
    :'refresh_thumbnail' => :'RefreshThumbnail',
  })
end

.swagger_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 51

def self.swagger_types
  super.merge({
    :'conformance' => :'String',
    :'zip64_mode' => :'String',
    :'compression_level' => :'String',
    :'refresh_thumbnail' => :'BOOLEAN',
  })
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 135

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      default_regular_font == o.default_regular_font &&
      delete_embedded_binary_objects == o.delete_embedded_binary_objects &&
      gradient_style == o.gradient_style &&
      font_fallback_rules == o.font_fallback_rules &&
      font_subst_rules == o.font_subst_rules &&
      skip_java_script_links == o.skip_java_script_links &&
      format == o.format &&
      conformance == o.conformance &&
      zip64_mode == o.zip64_mode &&
      compression_level == o.compression_level &&
      refresh_thumbnail == o.refresh_thumbnail
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


153
154
155
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 153

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



159
160
161
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 159

def hash
  [default_regular_font, delete_embedded_binary_objects, gradient_style, font_fallback_rules, font_subst_rules, skip_java_script_links, format, conformance, zip64_mode, compression_level, refresh_thumbnail].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



85
86
87
88
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 85

def list_invalid_properties
  invalid_properties = super
  invalid_properties
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



92
93
94
95
96
97
98
99
100
101
# File 'lib/aspose_slides_cloud/models/pptx_export_options.rb', line 92

def valid?
  return false if !super
  conformance_validator = EnumAttributeValidator.new('String', ['Ecma376', 'Iso29500Transitional', 'Iso29500Strict'])
  return false unless conformance_validator.valid?(@conformance)
  zip64_mode_validator = EnumAttributeValidator.new('String', ['Never', 'IfNecessary', 'Always'])
  return false unless zip64_mode_validator.valid?(@zip64_mode)
  compression_level_validator = EnumAttributeValidator.new('String', ['None', 'Level1', 'Level2', 'Level3', 'Level4', 'Level5', 'Level6', 'Level7', 'Level8', 'Level9'])
  return false unless compression_level_validator.valid?(@compression_level)
  true
end