Class: AsposeSlidesCloud::SlideShowTransition

Inherits:
BaseObject
  • Object
show all
Defined in:
lib/aspose_slides_cloud/models/slide_show_transition.rb

Overview

Slide Show Transition.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseObject

#_deserialize, #_to_hash, #build_from_hash, #to_body, #to_hash, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SlideShowTransition

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 167

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'Type')
    self.type = attributes[:'Type']
  end

  if attributes.has_key?(:'AdvanceAfter')
    self.advance_after = attributes[:'AdvanceAfter']
  end

  if attributes.has_key?(:'AdvanceAfterTime')
    self.advance_after_time = attributes[:'AdvanceAfterTime']
  end

  if attributes.has_key?(:'AdvanceOnClick')
    self.advance_on_click = attributes[:'AdvanceOnClick']
  end

  if attributes.has_key?(:'SoundIsBuiltIn')
    self.sound_is_built_in = attributes[:'SoundIsBuiltIn']
  end

  if attributes.has_key?(:'SoundLoop')
    self.sound_loop = attributes[:'SoundLoop']
  end

  if attributes.has_key?(:'SoundMode')
    self.sound_mode = attributes[:'SoundMode']
  end

  if attributes.has_key?(:'SoundName')
    self.sound_name = attributes[:'SoundName']
  end

  if attributes.has_key?(:'Speed')
    self.speed = attributes[:'Speed']
  end

  if attributes.has_key?(:'CornerDirection')
    self.corner_direction = attributes[:'CornerDirection']
  end

  if attributes.has_key?(:'EightDirection')
    self.eight_direction = attributes[:'EightDirection']
  end

  if attributes.has_key?(:'InOutDirection')
    self.in_out_direction = attributes[:'InOutDirection']
  end

  if attributes.has_key?(:'HasBounce')
    self.has_bounce = attributes[:'HasBounce']
  end

  if attributes.has_key?(:'SideDirection')
    self.side_direction = attributes[:'SideDirection']
  end

  if attributes.has_key?(:'Pattern')
    self.pattern = attributes[:'Pattern']
  end

  if attributes.has_key?(:'LeftRightDirection')
    self.left_right_direction = attributes[:'LeftRightDirection']
  end

  if attributes.has_key?(:'MorphType')
    self.morph_type = attributes[:'MorphType']
  end

  if attributes.has_key?(:'FromBlack')
    self.from_black = attributes[:'FromBlack']
  end

  if attributes.has_key?(:'OrientationDirection')
    self.orientation_direction = attributes[:'OrientationDirection']
  end

  if attributes.has_key?(:'ThroughBlack')
    self.through_black = attributes[:'ThroughBlack']
  end

  if attributes.has_key?(:'CornerAndCenterDirection')
    self.corner_and_center_direction = attributes[:'CornerAndCenterDirection']
  end

  if attributes.has_key?(:'ShredPattern')
    self.shred_pattern = attributes[:'ShredPattern']
  end

  if attributes.has_key?(:'Orientation')
    self.orientation = attributes[:'Orientation']
  end

  if attributes.has_key?(:'Spokes')
    self.spokes = attributes[:'Spokes']
  end

  if attributes.has_key?(:'Duration')
    self.duration = attributes[:'Duration']
  end
end

Instance Attribute Details

#advance_afterObject

Advance After



32
33
34
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 32

def advance_after
  @advance_after
end

#advance_after_timeObject

Advance After Time



35
36
37
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 35

def advance_after_time
  @advance_after_time
end

#advance_on_clickObject

Advance On Click



38
39
40
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 38

def advance_on_click
  @advance_on_click
end

#corner_and_center_directionObject

Orientation.



89
90
91
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 89

def corner_and_center_direction
  @corner_and_center_direction
end

#corner_directionObject

Corner Direction.



56
57
58
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 56

def corner_direction
  @corner_direction
end

#durationObject

The duration of the slide transition effect in milliseconds. If not set, the duration is determined automatically based on Speed and Type values.



101
102
103
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 101

def duration
  @duration
end

#eight_directionObject

Eight Direction.



59
60
61
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 59

def eight_direction
  @eight_direction
end

#from_blackObject

From Black.



80
81
82
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 80

def from_black
  @from_black
end

#has_bounceObject

Has Bounce.



65
66
67
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 65

def has_bounce
  @has_bounce
end

#in_out_directionObject

In/Out Direction.



62
63
64
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 62

def in_out_direction
  @in_out_direction
end

#left_right_directionObject

Left/Right Direction.



74
75
76
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 74

def left_right_direction
  @left_right_direction
end

#morph_typeObject

Morph Type.



77
78
79
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 77

def morph_type
  @morph_type
end

#orientationObject

Orientation.



95
96
97
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 95

def orientation
  @orientation
end

#orientation_directionObject

Orientation Direction.



83
84
85
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 83

def orientation_direction
  @orientation_direction
end

#patternObject

Pattern.



71
72
73
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 71

def pattern
  @pattern
end

#shred_patternObject

Shred Pattern.



92
93
94
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 92

def shred_pattern
  @shred_pattern
end

#side_directionObject

Side Direction.



68
69
70
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 68

def side_direction
  @side_direction
end

#sound_is_built_inObject

Sound Is Built In



41
42
43
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 41

def sound_is_built_in
  @sound_is_built_in
end

#sound_loopObject

Sound Loop



44
45
46
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 44

def sound_loop
  @sound_loop
end

#sound_modeObject

Sound Mode



47
48
49
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 47

def sound_mode
  @sound_mode
end

#sound_nameObject

Sound Name



50
51
52
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 50

def sound_name
  @sound_name
end

#speedObject

Speed



53
54
55
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 53

def speed
  @speed
end

#spokesObject

Spokes.



98
99
100
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 98

def spokes
  @spokes
end

#through_blackObject

Through Black.



86
87
88
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 86

def through_black
  @through_black
end

#typeObject

Transition Type



29
30
31
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 29

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 104

def self.attribute_map
  {
    :'type' => :'Type',
    :'advance_after' => :'AdvanceAfter',
    :'advance_after_time' => :'AdvanceAfterTime',
    :'advance_on_click' => :'AdvanceOnClick',
    :'sound_is_built_in' => :'SoundIsBuiltIn',
    :'sound_loop' => :'SoundLoop',
    :'sound_mode' => :'SoundMode',
    :'sound_name' => :'SoundName',
    :'speed' => :'Speed',
    :'corner_direction' => :'CornerDirection',
    :'eight_direction' => :'EightDirection',
    :'in_out_direction' => :'InOutDirection',
    :'has_bounce' => :'HasBounce',
    :'side_direction' => :'SideDirection',
    :'pattern' => :'Pattern',
    :'left_right_direction' => :'LeftRightDirection',
    :'morph_type' => :'MorphType',
    :'from_black' => :'FromBlack',
    :'orientation_direction' => :'OrientationDirection',
    :'through_black' => :'ThroughBlack',
    :'corner_and_center_direction' => :'CornerAndCenterDirection',
    :'shred_pattern' => :'ShredPattern',
    :'orientation' => :'Orientation',
    :'spokes' => :'Spokes',
    :'duration' => :'Duration',
  }
end

.swagger_typesObject

Attribute type mapping.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 135

def self.swagger_types
  {
    :'type' => :'String',
    :'advance_after' => :'BOOLEAN',
    :'advance_after_time' => :'Integer',
    :'advance_on_click' => :'BOOLEAN',
    :'sound_is_built_in' => :'BOOLEAN',
    :'sound_loop' => :'BOOLEAN',
    :'sound_mode' => :'String',
    :'sound_name' => :'String',
    :'speed' => :'String',
    :'corner_direction' => :'String',
    :'eight_direction' => :'String',
    :'in_out_direction' => :'String',
    :'has_bounce' => :'BOOLEAN',
    :'side_direction' => :'String',
    :'pattern' => :'String',
    :'left_right_direction' => :'String',
    :'morph_type' => :'String',
    :'from_black' => :'BOOLEAN',
    :'orientation_direction' => :'String',
    :'through_black' => :'BOOLEAN',
    :'corner_and_center_direction' => :'String',
    :'shred_pattern' => :'String',
    :'orientation' => :'String',
    :'spokes' => :'Integer',
    :'duration' => :'Integer',
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 457

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      advance_after == o.advance_after &&
      advance_after_time == o.advance_after_time &&
      advance_on_click == o.advance_on_click &&
      sound_is_built_in == o.sound_is_built_in &&
      sound_loop == o.sound_loop &&
      sound_mode == o.sound_mode &&
      sound_name == o.sound_name &&
      speed == o.speed &&
      corner_direction == o.corner_direction &&
      eight_direction == o.eight_direction &&
      in_out_direction == o.in_out_direction &&
      has_bounce == o.has_bounce &&
      side_direction == o.side_direction &&
      pattern == o.pattern &&
      left_right_direction == o.left_right_direction &&
      morph_type == o.morph_type &&
      from_black == o.from_black &&
      orientation_direction == o.orientation_direction &&
      through_black == o.through_black &&
      corner_and_center_direction == o.corner_and_center_direction &&
      shred_pattern == o.shred_pattern &&
      orientation == o.orientation &&
      spokes == o.spokes &&
      duration == o.duration
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


489
490
491
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 489

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



495
496
497
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 495

def hash
  [type, advance_after, advance_after_time, advance_on_click, sound_is_built_in, sound_loop, sound_mode, sound_name, speed, corner_direction, eight_direction, in_out_direction, has_bounce, side_direction, pattern, left_right_direction, morph_type, from_black, orientation_direction, through_black, corner_and_center_direction, shred_pattern, orientation, spokes, duration].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



276
277
278
279
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 276

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/aspose_slides_cloud/models/slide_show_transition.rb', line 283

def valid?
  type_validator = EnumAttributeValidator.new('String', ['None', 'Blinds', 'Checker', 'Circle', 'Comb', 'Cover', 'Cut', 'Diamond', 'Dissolve', 'Fade', 'Newsflash', 'Plus', 'Pull', 'Push', 'Random', 'RandomBar', 'Split', 'Strips', 'Wedge', 'Wheel', 'Wipe', 'Zoom', 'Vortex', 'Switch', 'Flip', 'Ripple', 'Honeycomb', 'Cube', 'Box', 'Rotate', 'Orbit', 'Doors', 'Window', 'Ferris', 'Gallery', 'Conveyor', 'Pan', 'Glitter', 'Warp', 'Flythrough', 'Flash', 'Shred', 'Reveal', 'WheelReverse', 'FallOver', 'Drape', 'Curtains', 'Wind', 'Prestige', 'Fracture', 'Crush', 'PeelOff', 'PageCurlDouble', 'PageCurlSingle', 'Airplane', 'Origami', 'Morph'])
  return false unless type_validator.valid?(@type)
  sound_mode_validator = EnumAttributeValidator.new('String', ['StartSound', 'StopPrevoiusSound', 'NotDefined'])
  return false unless sound_mode_validator.valid?(@sound_mode)
  speed_validator = EnumAttributeValidator.new('String', ['Fast', 'Medium', 'Slow'])
  return false unless speed_validator.valid?(@speed)
  corner_direction_validator = EnumAttributeValidator.new('String', ['LeftDown', 'LeftUp', 'RightDown', 'RightUp'])
  return false unless corner_direction_validator.valid?(@corner_direction)
  eight_direction_validator = EnumAttributeValidator.new('String', ['LeftDown', 'LeftUp', 'RightDown', 'RightUp', 'Left', 'Up', 'Down', 'Right'])
  return false unless eight_direction_validator.valid?(@eight_direction)
  in_out_direction_validator = EnumAttributeValidator.new('String', ['In', 'Out'])
  return false unless in_out_direction_validator.valid?(@in_out_direction)
  side_direction_validator = EnumAttributeValidator.new('String', ['Left', 'Up', 'Down', 'Right'])
  return false unless side_direction_validator.valid?(@side_direction)
  pattern_validator = EnumAttributeValidator.new('String', ['Diamond', 'Hexagon'])
  return false unless pattern_validator.valid?(@pattern)
  left_right_direction_validator = EnumAttributeValidator.new('String', ['Left', 'Right'])
  return false unless left_right_direction_validator.valid?(@left_right_direction)
  morph_type_validator = EnumAttributeValidator.new('String', ['ByObject', 'ByWord', 'ByChar'])
  return false unless morph_type_validator.valid?(@morph_type)
  orientation_direction_validator = EnumAttributeValidator.new('String', ['Horizontal', 'Vertical'])
  return false unless orientation_direction_validator.valid?(@orientation_direction)
  corner_and_center_direction_validator = EnumAttributeValidator.new('String', ['LeftDown', 'LeftUp', 'RightDown', 'RightUp', 'Center'])
  return false unless corner_and_center_direction_validator.valid?(@corner_and_center_direction)
  shred_pattern_validator = EnumAttributeValidator.new('String', ['Strip', 'Rectangle'])
  return false unless shred_pattern_validator.valid?(@shred_pattern)
  orientation_validator = EnumAttributeValidator.new('String', ['Horizontal', 'Vertical'])
  return false unless orientation_validator.valid?(@orientation)
  true
end