Class: AsposeSlidesCloud::SmartArt

Inherits:
ShapeBase show all
Defined in:
lib/aspose_slides_cloud/models/smart_art.rb

Overview

Represents SmartArt shape resource.

Instance Attribute Summary collapse

Attributes inherited from ShapeBase

#alternative_text, #alternative_text_title, #effect_format, #fill_format, #height, #hidden, #hyperlink_click, #hyperlink_mouse_over, #is_decorative, #line_format, #name, #three_d_format, #type, #width, #x, #y, #z_order_position

Attributes inherited from ResourceBase

#alternate_links, #self_uri

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseObject

#_deserialize, #_to_hash, #build_from_hash, #to_body, #to_hash, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SmartArt

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 72

def initialize(attributes = {})
  super

  if attributes.has_key?(:'Layout')
    self.layout = attributes[:'Layout']
  end

  if attributes.has_key?(:'QuickStyle')
    self.quick_style = attributes[:'QuickStyle']
  end

  if attributes.has_key?(:'ColorStyle')
    self.color_style = attributes[:'ColorStyle']
  end

  if attributes.has_key?(:'Nodes')
    if (value = attributes[:'Nodes']).is_a?(Array)
      self.nodes = value
    end
  end

  if attributes.has_key?(:'IsReversed')
    self.is_reversed = attributes[:'IsReversed']
  end

  if attributes.has_key?(:'DefaultParagraphFormat')
    self.default_paragraph_format = attributes[:'DefaultParagraphFormat']
  end
  self.type = 'SmartArt'
end

Instance Attribute Details

#color_styleObject

Color style.



35
36
37
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 35

def color_style
  @color_style
end

#default_paragraph_formatObject

Default paragraph format applied to all nodes. Write-only: not populated on read since there is no corresponding property at the SmartArt shape level in Aspose.Slides.



44
45
46
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 44

def default_paragraph_format
  @default_paragraph_format
end

#is_reversedObject

The state of the SmartArt diagram with regard to (left-to-right) LTR or (right-to-left) RTL, if the diagram supports reversal.



41
42
43
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 41

def is_reversed
  @is_reversed
end

#layoutObject

Layout type.



29
30
31
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 29

def layout
  @layout
end

#nodesObject

Collection of nodes in SmartArt object.



38
39
40
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 38

def nodes
  @nodes
end

#quick_styleObject

Quick style.



32
33
34
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 32

def quick_style
  @quick_style
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 47

def self.attribute_map
  super.merge({
    :'layout' => :'Layout',
    :'quick_style' => :'QuickStyle',
    :'color_style' => :'ColorStyle',
    :'nodes' => :'Nodes',
    :'is_reversed' => :'IsReversed',
    :'default_paragraph_format' => :'DefaultParagraphFormat',
  })
end

.swagger_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 59

def self.swagger_types
  super.merge({
    :'layout' => :'String',
    :'quick_style' => :'String',
    :'color_style' => :'String',
    :'nodes' => :'Array<SmartArtNode>',
    :'is_reversed' => :'BOOLEAN',
    :'default_paragraph_format' => :'ParagraphFormat',
  })
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 170

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      self_uri == o.self_uri &&
      alternate_links == o.alternate_links &&
      name == o.name &&
      width == o.width &&
      height == o.height &&
      alternative_text == o.alternative_text &&
      alternative_text_title == o.alternative_text_title &&
      hidden == o.hidden &&
      is_decorative == o.is_decorative &&
      x == o.x &&
      y == o.y &&
      z_order_position == o.z_order_position &&
      fill_format == o.fill_format &&
      effect_format == o.effect_format &&
      three_d_format == o.three_d_format &&
      line_format == o.line_format &&
      hyperlink_click == o.hyperlink_click &&
      hyperlink_mouse_over == o.hyperlink_mouse_over &&
      type == o.type &&
      layout == o.layout &&
      quick_style == o.quick_style &&
      color_style == o.color_style &&
      nodes == o.nodes &&
      is_reversed == o.is_reversed &&
      default_paragraph_format == o.default_paragraph_format
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 202

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



208
209
210
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 208

def hash
  [self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, is_decorative, x, y, z_order_position, fill_format, effect_format, three_d_format, line_format, hyperlink_click, hyperlink_mouse_over, type, layout, quick_style, color_style, nodes, is_reversed, default_paragraph_format].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 105

def list_invalid_properties
  invalid_properties = super
  if @layout.nil?
    invalid_properties.push('invalid value for "layout", layout cannot be nil.')
  end

  if @quick_style.nil?
    invalid_properties.push('invalid value for "quick_style", quick_style cannot be nil.')
  end

  if @color_style.nil?
    invalid_properties.push('invalid value for "color_style", color_style cannot be nil.')
  end

  invalid_properties
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/aspose_slides_cloud/models/smart_art.rb', line 124

def valid?
  return false if !super
  return false if @layout.nil?
  layout_validator = EnumAttributeValidator.new('String', ['AccentProcess', 'AccentedPicture', 'AlternatingFlow', 'AlternatingHexagons', 'AlternatingPictureBlocks', 'AlternatingPictureCircles', 'ArrowRibbon', 'AscendingPictureAccentProcess', 'Balance', 'BasicBendingProcess', 'BasicBlockList', 'BasicChevronProcess', 'BasicCycle', 'BasicMatrix', 'BasicPie', 'BasicProcess', 'BasicPyramid', 'BasicRadial', 'BasicTarget', 'BasicTimeline', 'BasicVenn', 'BendingPictureAccentList', 'BendingPictureBlocks', 'BendingPictureCaption', 'BendingPictureCaptionList', 'BendingPictureSemiTransparentText', 'BlockCycle', 'BubblePictureList', 'CaptionedPictures', 'ChevronList', 'CircleAccentTimeline', 'CircleArrowProcess', 'CirclePictureHierarchy', 'CircleRelationship', 'CircularBendingProcess', 'CircularPictureCallout', 'ClosedChevronProcess', 'ContinuousArrowProcess', 'ContinuousBlockProcess', 'ContinuousCycle', 'ContinuousPictureList', 'ConvergingArrows', 'ConvergingRadial', 'CounterbalanceArrows', 'CycleMatrix', 'DescendingBlockList', 'DescendingProcess', 'DetailedProcess', 'DivergingArrows', 'DivergingRadial', 'Equation', 'FramedTextPicture', 'Funnel', 'Gear', 'GridMatrix', 'GroupedList', 'HalfCircleOrganizationChart', 'HexagonCluster', 'Hierarchy', 'HierarchyList', 'HorizontalBulletList', 'HorizontalHierarchy', 'HorizontalLabeledHierarchy', 'HorizontalMultiLevelHierarchy', 'HorizontalOrganizationChart', 'HorizontalPictureList', 'IncreasingArrowsProcess', 'IncreasingCircleProcess', 'InvertedPyramid', 'LabeledHierarchy', 'LinearVenn', 'LinedList', 'MultidirectionalCycle', 'NameandTitleOrganizationChart', 'NestedTarget', 'NondirectionalCycle', 'OpposingArrows', 'OpposingIdeas', 'OrganizationChart', 'PhasedProcess', 'PictureAccentBlocks', 'PictureAccentList', 'PictureAccentProcess', 'PictureCaptionList', 'PictureGrid', 'PictureLineup', 'PictureStrips', 'PieProcess', 'PlusandMinus', 'ProcessArrows', 'ProcessList', 'PyramidList', 'RadialCluster', 'RadialCycle', 'RadialList', 'RadialVenn', 'RandomToResultProcess', 'RepeatingBendingProcess', 'ReverseList', 'SegmentedCycle', 'SegmentedProcess', 'SegmentedPyramid', 'SnapshotPictureList', 'SpiralPicture', 'SquareAccentList', 'StackedList', 'StackedVenn', 'StaggeredProcess', 'StepDownProcess', 'StepUpProcess', 'SubStepProcess', 'TableHierarchy', 'TableList', 'TargetList', 'TextCycle', 'TitlePictureLineup', 'TitledMatrix', 'TitledPictureAccentList', 'TitledPictureBlocks', 'TrapezoidList', 'UpwardArrow', 'VerticalAccentList', 'VerticalArrowList', 'VerticalBendingProcess', 'VerticalBlockList', 'VerticalBoxList', 'VerticalBulletList', 'VerticalChevronList', 'VerticalCircleList', 'VerticalCurvedList', 'VerticalEquation', 'VerticalPictureAccentList', 'VerticalPictureList', 'VerticalProcess', 'Custom', 'PictureOrganizationChart'])
  return false unless layout_validator.valid?(@layout)
  return false if @quick_style.nil?
  quick_style_validator = EnumAttributeValidator.new('String', ['SimpleFill', 'WhiteOutline', 'SubtleEffect', 'ModerateEffect', 'IntenceEffect', 'Polished', 'Inset', 'Cartoon', 'Powder', 'BrickScene', 'FlatScene', 'MetallicScene', 'SunsetScene', 'BirdsEyeScene'])
  return false unless quick_style_validator.valid?(@quick_style)
  return false if @color_style.nil?
  color_style_validator = EnumAttributeValidator.new('String', ['Dark1Outline', 'Dark2Outline', 'DarkFill', 'ColorfulAccentColors', 'ColorfulAccentColors2to3', 'ColorfulAccentColors3to4', 'ColorfulAccentColors4to5', 'ColorfulAccentColors5to6', 'ColoredOutlineAccent1', 'ColoredFillAccent1', 'GradientRangeAccent1', 'GradientLoopAccent1', 'TransparentGradientRangeAccent1', 'ColoredOutlineAccent2', 'ColoredFillAccent2', 'GradientRangeAccent2', 'GradientLoopAccent2', 'TransparentGradientRangeAccent2', 'ColoredOutlineAccent3', 'ColoredFillAccent3', 'GradientRangeAccent3', 'GradientLoopAccent3', 'TransparentGradientRangeAccent3', 'ColoredOutlineAccent4', 'ColoredFillAccent4', 'GradientRangeAccent4', 'GradientLoopAccent4', 'TransparentGradientRangeAccent4', 'ColoredOutlineAccent5', 'ColoredFillAccent5', 'GradientRangeAccent5', 'GradientLoopAccent5', 'TransparentGradientRangeAccent5', 'ColoredOutlineAccent6', 'ColoredFillAccent6', 'GradientRangeAccent6', 'GradientLoopAccent6', 'TransparentGradientRangeAccent6'])
  return false unless color_style_validator.valid?(@color_style)
  true
end