Class: AsposeSlidesCloud::AudioFrame
- Inherits:
-
GeometryShape
- Object
- BaseObject
- ResourceBase
- ShapeBase
- GeometryShape
- AsposeSlidesCloud::AudioFrame
- Defined in:
- lib/aspose_slides_cloud/models/audio_frame.rb
Overview
Represents AudioFrame resource.
Instance Attribute Summary collapse
-
#audio_cd_end_track ⇒ Object
Returns or sets a last track index.
-
#audio_cd_end_track_time ⇒ Object
Returns or sets a last track time.
-
#audio_cd_start_track ⇒ Object
Returns or sets a start track index.
-
#audio_cd_start_track_time ⇒ Object
Returns or sets a start track time.
-
#base64_data ⇒ Object
Audio data encoded in base64.
-
#embedded ⇒ Object
Determines whether a sound is embedded to a presentation.
-
#fade_in_duration ⇒ Object
Time duration for the initial fade-in of the media in milliseconds.
-
#fade_out_duration ⇒ Object
Time duration for the ending fade-out of the media in milliseconds.
-
#hide_at_showing ⇒ Object
Determines whether an AudioFrame is hidden.
-
#picture_fill_format ⇒ Object
Picture fill format.
-
#play_across_slides ⇒ Object
Determines whether an audio is playing across the slides.
-
#play_loop_mode ⇒ Object
Determines whether an audio is looped.
-
#play_mode ⇒ Object
Returns or sets the audio play mode.
-
#rewind_audio ⇒ Object
Determines whether audio is automatically rewound to start after playing.
-
#trim_from_end ⇒ Object
Time duration to be removed from the end of the media during playback in milliseconds.
-
#trim_from_start ⇒ Object
Time duration to be removed from the beginning of the media during playback in milliseconds.
-
#volume ⇒ Object
Returns or sets the audio volume.
-
#volume_value ⇒ Object
Audio volume percent.
Attributes inherited from GeometryShape
Attributes inherited from ShapeBase
#alternative_text, #alternative_text_title, #effect_format, #fill_format, #height, #hidden, #hyperlink_click, #hyperlink_mouse_over, #is_decorative, #line_format, #name, #three_d_format, #type, #width, #x, #y, #z_order_position
Attributes inherited from ResourceBase
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AudioFrame
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from BaseObject
#_deserialize, #_to_hash, #build_from_hash, #to_body, #to_hash, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AudioFrame
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 132 def initialize(attributes = {}) super if attributes.has_key?(:'AudioCdEndTrack') self.audio_cd_end_track = attributes[:'AudioCdEndTrack'] end if attributes.has_key?(:'AudioCdEndTrackTime') self.audio_cd_end_track_time = attributes[:'AudioCdEndTrackTime'] end if attributes.has_key?(:'AudioCdStartTrack') self.audio_cd_start_track = attributes[:'AudioCdStartTrack'] end if attributes.has_key?(:'AudioCdStartTrackTime') self.audio_cd_start_track_time = attributes[:'AudioCdStartTrackTime'] end if attributes.has_key?(:'Embedded') self. = attributes[:'Embedded'] end if attributes.has_key?(:'HideAtShowing') self.hide_at_showing = attributes[:'HideAtShowing'] end if attributes.has_key?(:'PlayLoopMode') self.play_loop_mode = attributes[:'PlayLoopMode'] end if attributes.has_key?(:'PlayMode') self.play_mode = attributes[:'PlayMode'] end if attributes.has_key?(:'Volume') self.volume = attributes[:'Volume'] end if attributes.has_key?(:'VolumeValue') self.volume_value = attributes[:'VolumeValue'] end if attributes.has_key?(:'Base64Data') self.base64_data = attributes[:'Base64Data'] end if attributes.has_key?(:'PlayAcrossSlides') self. = attributes[:'PlayAcrossSlides'] end if attributes.has_key?(:'RewindAudio') self.rewind_audio = attributes[:'RewindAudio'] end if attributes.has_key?(:'FadeInDuration') self.fade_in_duration = attributes[:'FadeInDuration'] end if attributes.has_key?(:'FadeOutDuration') self.fade_out_duration = attributes[:'FadeOutDuration'] end if attributes.has_key?(:'TrimFromStart') self.trim_from_start = attributes[:'TrimFromStart'] end if attributes.has_key?(:'TrimFromEnd') self.trim_from_end = attributes[:'TrimFromEnd'] end if attributes.has_key?(:'PictureFillFormat') self.picture_fill_format = attributes[:'PictureFillFormat'] end self.type = 'AudioFrame' end |
Instance Attribute Details
#audio_cd_end_track ⇒ Object
Returns or sets a last track index.
29 30 31 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 29 def audio_cd_end_track @audio_cd_end_track end |
#audio_cd_end_track_time ⇒ Object
Returns or sets a last track time.
32 33 34 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 32 def audio_cd_end_track_time @audio_cd_end_track_time end |
#audio_cd_start_track ⇒ Object
Returns or sets a start track index.
35 36 37 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 35 def audio_cd_start_track @audio_cd_start_track end |
#audio_cd_start_track_time ⇒ Object
Returns or sets a start track time.
38 39 40 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 38 def audio_cd_start_track_time @audio_cd_start_track_time end |
#base64_data ⇒ Object
Audio data encoded in base64.
59 60 61 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 59 def base64_data @base64_data end |
#embedded ⇒ Object
Determines whether a sound is embedded to a presentation.
41 42 43 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 41 def @embedded end |
#fade_in_duration ⇒ Object
Time duration for the initial fade-in of the media in milliseconds.
68 69 70 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 68 def fade_in_duration @fade_in_duration end |
#fade_out_duration ⇒ Object
Time duration for the ending fade-out of the media in milliseconds.
71 72 73 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 71 def fade_out_duration @fade_out_duration end |
#hide_at_showing ⇒ Object
Determines whether an AudioFrame is hidden.
44 45 46 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 44 def hide_at_showing @hide_at_showing end |
#picture_fill_format ⇒ Object
Picture fill format.
80 81 82 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 80 def picture_fill_format @picture_fill_format end |
#play_across_slides ⇒ Object
Determines whether an audio is playing across the slides.
62 63 64 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 62 def @play_across_slides end |
#play_loop_mode ⇒ Object
Determines whether an audio is looped.
47 48 49 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 47 def play_loop_mode @play_loop_mode end |
#play_mode ⇒ Object
Returns or sets the audio play mode.
50 51 52 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 50 def play_mode @play_mode end |
#rewind_audio ⇒ Object
Determines whether audio is automatically rewound to start after playing.
65 66 67 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 65 def rewind_audio @rewind_audio end |
#trim_from_end ⇒ Object
Time duration to be removed from the end of the media during playback in milliseconds.
77 78 79 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 77 def trim_from_end @trim_from_end end |
#trim_from_start ⇒ Object
Time duration to be removed from the beginning of the media during playback in milliseconds.
74 75 76 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 74 def trim_from_start @trim_from_start end |
#volume ⇒ Object
Returns or sets the audio volume.
53 54 55 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 53 def volume @volume end |
#volume_value ⇒ Object
Audio volume percent.
56 57 58 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 56 def volume_value @volume_value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 83 def self.attribute_map super.merge({ :'audio_cd_end_track' => :'AudioCdEndTrack', :'audio_cd_end_track_time' => :'AudioCdEndTrackTime', :'audio_cd_start_track' => :'AudioCdStartTrack', :'audio_cd_start_track_time' => :'AudioCdStartTrackTime', :'embedded' => :'Embedded', :'hide_at_showing' => :'HideAtShowing', :'play_loop_mode' => :'PlayLoopMode', :'play_mode' => :'PlayMode', :'volume' => :'Volume', :'volume_value' => :'VolumeValue', :'base64_data' => :'Base64Data', :'play_across_slides' => :'PlayAcrossSlides', :'rewind_audio' => :'RewindAudio', :'fade_in_duration' => :'FadeInDuration', :'fade_out_duration' => :'FadeOutDuration', :'trim_from_start' => :'TrimFromStart', :'trim_from_end' => :'TrimFromEnd', :'picture_fill_format' => :'PictureFillFormat', }) end |
.swagger_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 107 def self.swagger_types super.merge({ :'audio_cd_end_track' => :'Integer', :'audio_cd_end_track_time' => :'Integer', :'audio_cd_start_track' => :'Integer', :'audio_cd_start_track_time' => :'Integer', :'embedded' => :'BOOLEAN', :'hide_at_showing' => :'BOOLEAN', :'play_loop_mode' => :'BOOLEAN', :'play_mode' => :'String', :'volume' => :'String', :'volume_value' => :'Float', :'base64_data' => :'String', :'play_across_slides' => :'BOOLEAN', :'rewind_audio' => :'BOOLEAN', :'fade_in_duration' => :'Float', :'fade_out_duration' => :'Float', :'trim_from_start' => :'Float', :'trim_from_end' => :'Float', :'picture_fill_format' => :'PictureFill', }) end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 249 def ==(o) return true if self.equal?(o) self.class == o.class && self_uri == o.self_uri && alternate_links == o.alternate_links && name == o.name && width == o.width && height == o.height && alternative_text == o.alternative_text && alternative_text_title == o.alternative_text_title && hidden == o.hidden && is_decorative == o.is_decorative && x == o.x && y == o.y && z_order_position == o.z_order_position && fill_format == o.fill_format && effect_format == o.effect_format && three_d_format == o.three_d_format && line_format == o.line_format && hyperlink_click == o.hyperlink_click && hyperlink_mouse_over == o.hyperlink_mouse_over && type == o.type && shape_type == o.shape_type && audio_cd_end_track == o.audio_cd_end_track && audio_cd_end_track_time == o.audio_cd_end_track_time && audio_cd_start_track == o.audio_cd_start_track && audio_cd_start_track_time == o.audio_cd_start_track_time && == o. && hide_at_showing == o.hide_at_showing && play_loop_mode == o.play_loop_mode && play_mode == o.play_mode && volume == o.volume && volume_value == o.volume_value && base64_data == o.base64_data && == o. && rewind_audio == o.rewind_audio && fade_in_duration == o.fade_in_duration && fade_out_duration == o.fade_out_duration && trim_from_start == o.trim_from_start && trim_from_end == o.trim_from_end && picture_fill_format == o.picture_fill_format end |
#eql?(o) ⇒ Boolean
294 295 296 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 294 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
300 301 302 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 300 def hash [self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, is_decorative, x, y, z_order_position, fill_format, effect_format, three_d_format, line_format, hyperlink_click, hyperlink_mouse_over, type, shape_type, audio_cd_end_track, audio_cd_end_track_time, audio_cd_start_track, audio_cd_start_track_time, , hide_at_showing, play_loop_mode, play_mode, volume, volume_value, base64_data, , rewind_audio, fade_in_duration, fade_out_duration, trim_from_start, trim_from_end, picture_fill_format].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
211 212 213 214 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 211 def list_invalid_properties invalid_properties = super invalid_properties end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
218 219 220 221 222 223 224 225 |
# File 'lib/aspose_slides_cloud/models/audio_frame.rb', line 218 def valid? return false if !super play_mode_validator = EnumAttributeValidator.new('String', ['Auto', 'OnClick', 'AllSlides', 'InClickSequence', 'Mixed']) return false unless play_mode_validator.valid?(@play_mode) volume_validator = EnumAttributeValidator.new('String', ['Mute', 'Low', 'Medium', 'Loud', 'Mixed']) return false unless volume_validator.valid?(@volume) true end |