Class: AsposeSlidesCloud::Configuration
- Inherits:
-
Object
- Object
- AsposeSlidesCloud::Configuration
- Defined in:
- lib/aspose_slides_cloud/configuration.rb
Instance Attribute Summary collapse
-
#access_token ⇒ Object
Defines the access token (Bearer) used with OAuth2.
-
#app_key ⇒ Hash
Defines API secret key used for authentication.
-
#app_sid ⇒ Hash
Defines API keys used for authentication.
-
#base_url ⇒ Object
Defines base url.
-
#cert_file ⇒ Object
TLS/SSL setting Client certificate file (for client certificate).
-
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation.
-
#custom_headers ⇒ Hash
Custom HTTP headers for all requests.
-
#debugging ⇒ true, false
Set this to enable/disable debugging.
-
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
-
#http_request_timeout ⇒ Object
The time limit for HTTP request in seconds.
-
#inject_format ⇒ Object
Returns the value of attribute inject_format.
-
#key_file ⇒ Object
TLS/SSL setting Client private key file (for client certificate).
-
#logger ⇒ #debug
Defines the logger used for debugging.
-
#params_encoding ⇒ Object
Set this to customize parameters encoding of array parameter with multi collectionFormat.
-
#ssl_ca_cert ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
-
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files (for API endpoints that have file response).
-
#timeout ⇒ Object
slides operaion timeout in seconds.
-
#verify_ssl ⇒ true, false
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server.
-
#verify_ssl_host ⇒ true, false
TLS/SSL setting Set this to false to skip verifying SSL host name Default to true.
-
#version ⇒ Object
Defines platform version.
Class Method Summary collapse
-
.default ⇒ Object
The default Configuration object.
Instance Method Summary collapse
- #async_base_url ⇒ Object
- #async_base_url=(async_base_url) ⇒ Object
- #auth_base_url ⇒ Object
- #auth_base_url=(auth_base_url) ⇒ Object
- #base_path ⇒ Object
- #configure {|_self| ... } ⇒ Object
- #getUrlHostPart(url) ⇒ Object
-
#initialize {|_self| ... } ⇒ Configuration
constructor
A new instance of Configuration.
Constructor Details
#initialize {|_self| ... } ⇒ Configuration
Returns a new instance of Configuration.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 129 def initialize @base_url = 'https://api.aspose.cloud' @version = 'v3.0' @http_request_timeout = 300 @timeout = 0 @custom_headers = Hash.new @client_side_validation = true @verify_ssl = true @verify_ssl_host = false @params_encoding = nil @cert_file = nil @key_file = nil @debugging = false @inject_format = false @force_ending_format = false @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT) yield(self) if block_given? end |
Instance Attribute Details
#access_token ⇒ Object
Defines the access token (Bearer) used with OAuth2.
44 45 46 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 44 def access_token @access_token end |
#app_key ⇒ Hash
Defines API secret key used for authentication.
41 42 43 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 41 def app_key @app_key end |
#app_sid ⇒ Hash
Defines API keys used for authentication.
36 37 38 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 36 def app_sid @app_sid end |
#base_url ⇒ Object
Defines base url
28 29 30 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 28 def base_url @base_url end |
#cert_file ⇒ Object
TLS/SSL setting Client certificate file (for client certificate)
112 113 114 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 112 def cert_file @cert_file end |
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation. Default to true.
77 78 79 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 77 def client_side_validation @client_side_validation end |
#custom_headers ⇒ Hash
Custom HTTP headers for all requests.
81 82 83 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 81 def custom_headers @custom_headers end |
#debugging ⇒ true, false
Set this to enable/disable debugging. When enabled (set to true), HTTP request/response details will be logged with ‘logger.debug` (see the `logger` attribute). Default to false.
51 52 53 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 51 def debugging @debugging end |
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
127 128 129 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 127 def force_ending_format @force_ending_format end |
#http_request_timeout ⇒ Object
The time limit for HTTP request in seconds. Default to 300.
72 73 74 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 72 def http_request_timeout @http_request_timeout end |
#inject_format ⇒ Object
Returns the value of attribute inject_format.
125 126 127 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 125 def inject_format @inject_format end |
#key_file ⇒ Object
TLS/SSL setting Client private key file (for client certificate)
116 117 118 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 116 def key_file @key_file end |
#logger ⇒ #debug
Defines the logger used for debugging. Default to ‘Rails.logger` (when in Rails) or logging to STDOUT.
57 58 59 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 57 def logger @logger end |
#params_encoding ⇒ Object
Set this to customize parameters encoding of array parameter with multi collectionFormat. Default to nil.
github.com/typhoeus/ethon/blob/master/lib/ethon/easy/queryable.rb#L96
123 124 125 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 123 def params_encoding @params_encoding end |
#ssl_ca_cert ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
github.com/typhoeus/typhoeus/blob/master/lib/typhoeus/easy_factory.rb#L145
108 109 110 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 108 def ssl_ca_cert @ssl_ca_cert end |
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files (for API endpoints that have file response). Default to use ‘Tempfile`.
64 65 66 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 64 def temp_folder_path @temp_folder_path end |
#timeout ⇒ Object
slides operaion timeout in seconds. The timeout applies to the Slides operation, not to the HTTP request. Default to 0 (no timeout).
68 69 70 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 68 def timeout @timeout end |
#verify_ssl ⇒ true, false
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.
90 91 92 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 90 def verify_ssl @verify_ssl end |
#verify_ssl_host ⇒ true, false
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting Set this to false to skip verifying SSL host name Default to true.
99 100 101 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 99 def verify_ssl_host @verify_ssl_host end |
#version ⇒ Object
Defines platform version
31 32 33 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 31 def version @version end |
Class Method Details
.default ⇒ Object
The default Configuration object.
150 151 152 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 150 def self.default @@default ||= Configuration.new end |
Instance Method Details
#async_base_url ⇒ Object
162 163 164 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 162 def async_base_url @async_base_url || @base_url end |
#async_base_url=(async_base_url) ⇒ Object
166 167 168 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 166 def async_base_url=(async_base_url) @async_base_url = getUrlHostPart(async_base_url) end |
#auth_base_url ⇒ Object
170 171 172 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 170 def auth_base_url @auth_base_url || @base_url end |
#auth_base_url=(auth_base_url) ⇒ Object
174 175 176 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 174 def auth_base_url=(auth_base_url) @auth_base_url = getUrlHostPart(auth_base_url) end |
#base_path ⇒ Object
192 193 194 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 192 def base_path "#{[base_url, version].join('/')}".sub(/\/+\z/, '') end |
#configure {|_self| ... } ⇒ Object
154 155 156 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 154 def configure yield(self) if block_given? end |
#getUrlHostPart(url) ⇒ Object
178 179 180 181 182 183 184 |
# File 'lib/aspose_slides_cloud/configuration.rb', line 178 def getUrlHostPart(url) parts = url.split('//') if (parts.length > 1) return "#{parts[0]}//#{parts[1].split('/').first}"; end parts[0].split('/').first end |