Class: AsposeSlidesCloud::ExportOptions
- Inherits:
-
BaseObject
- Object
- BaseObject
- AsposeSlidesCloud::ExportOptions
- Defined in:
- lib/aspose_slides_cloud/models/export_options.rb
Overview
Represents export options for whole presentation.
Direct Known Subclasses
Html5ExportOptions, HtmlExportOptions, ImageExportOptionsBase, MarkdownExportOptions, PdfExportOptions, PptxExportOptions, SvgExportOptions, SwfExportOptions, VideoExportOptions, XamlExportOptions, XpsExportOptions
Instance Attribute Summary collapse
-
#default_regular_font ⇒ Object
Default regular font for rendering the presentation.
-
#delete_embedded_binary_objects ⇒ Object
True to delete delete all embedded binary objects.
-
#font_fallback_rules ⇒ Object
Gets of sets list of font fallback rules.
-
#font_subst_rules ⇒ Object
Gets of sets list of font substitution rules.
-
#format ⇒ Object
Returns the value of attribute format.
-
#gradient_style ⇒ Object
Default regular font for rendering the presentation.
-
#skip_java_script_links ⇒ Object
True to skip hyperlinks with javascript calls when saving the presentation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExportOptions
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from BaseObject
#_deserialize, #_to_hash, #build_from_hash, #to_body, #to_hash, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExportOptions
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 76 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'DefaultRegularFont') self.default_regular_font = attributes[:'DefaultRegularFont'] end if attributes.has_key?(:'DeleteEmbeddedBinaryObjects') self. = attributes[:'DeleteEmbeddedBinaryObjects'] end if attributes.has_key?(:'GradientStyle') self.gradient_style = attributes[:'GradientStyle'] end if attributes.has_key?(:'FontFallbackRules') if (value = attributes[:'FontFallbackRules']).is_a?(Array) self.font_fallback_rules = value end end if attributes.has_key?(:'FontSubstRules') if (value = attributes[:'FontSubstRules']).is_a?(Array) self.font_subst_rules = value end end if attributes.has_key?(:'SkipJavaScriptLinks') self.skip_java_script_links = attributes[:'SkipJavaScriptLinks'] end if attributes.has_key?(:'Format') self.format = attributes[:'Format'] end end |
Instance Attribute Details
#default_regular_font ⇒ Object
Default regular font for rendering the presentation.
29 30 31 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 29 def default_regular_font @default_regular_font end |
#delete_embedded_binary_objects ⇒ Object
True to delete delete all embedded binary objects.
32 33 34 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 32 def @delete_embedded_binary_objects end |
#font_fallback_rules ⇒ Object
Gets of sets list of font fallback rules.
38 39 40 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 38 def font_fallback_rules @font_fallback_rules end |
#font_subst_rules ⇒ Object
Gets of sets list of font substitution rules.
41 42 43 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 41 def font_subst_rules @font_subst_rules end |
#format ⇒ Object
Returns the value of attribute format.
46 47 48 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 46 def format @format end |
#gradient_style ⇒ Object
Default regular font for rendering the presentation.
35 36 37 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 35 def gradient_style @gradient_style end |
#skip_java_script_links ⇒ Object
True to skip hyperlinks with javascript calls when saving the presentation.
44 45 46 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 44 def skip_java_script_links @skip_java_script_links end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 49 def self.attribute_map { :'default_regular_font' => :'DefaultRegularFont', :'delete_embedded_binary_objects' => :'DeleteEmbeddedBinaryObjects', :'gradient_style' => :'GradientStyle', :'font_fallback_rules' => :'FontFallbackRules', :'font_subst_rules' => :'FontSubstRules', :'skip_java_script_links' => :'SkipJavaScriptLinks', :'format' => :'Format', } end |
.swagger_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 62 def self.swagger_types { :'default_regular_font' => :'String', :'delete_embedded_binary_objects' => :'BOOLEAN', :'gradient_style' => :'String', :'font_fallback_rules' => :'Array<FontFallbackRule>', :'font_subst_rules' => :'Array<FontSubstRule>', :'skip_java_script_links' => :'BOOLEAN', :'format' => :'String', } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 142 def ==(o) return true if self.equal?(o) self.class == o.class && default_regular_font == o.default_regular_font && == o. && gradient_style == o.gradient_style && font_fallback_rules == o.font_fallback_rules && font_subst_rules == o.font_subst_rules && skip_java_script_links == o.skip_java_script_links && format == o.format end |
#eql?(o) ⇒ Boolean
156 157 158 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 156 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 162 def hash [default_regular_font, , gradient_style, font_fallback_rules, font_subst_rules, skip_java_script_links, format].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 117 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 128 |
# File 'lib/aspose_slides_cloud/models/export_options.rb', line 124 def valid? gradient_style_validator = EnumAttributeValidator.new('String', ['Default', 'PowerPointUI']) return false unless gradient_style_validator.valid?(@gradient_style) true end |