Class: AsposeSlidesCloud::SwfExportOptions
- Inherits:
-
ExportOptions
- Object
- BaseObject
- ExportOptions
- AsposeSlidesCloud::SwfExportOptions
- Defined in:
- lib/aspose_slides_cloud/models/swf_export_options.rb
Overview
Provides options that control how a presentation is saved in SWF format.
Instance Attribute Summary collapse
-
#compressed ⇒ Object
Specifies whether the generated SWF document should be compressed or not.
-
#enable_context_menu ⇒ Object
Enable/disable context menu.
-
#jpeg_quality ⇒ Object
Specifies the quality of JPEG images.
-
#logo_image ⇒ Object
Image that will be displayed as logo in the top right corner of the viewer.
-
#logo_link ⇒ Object
Gets or sets the full hyperlink address for a logo.
-
#show_bottom_pane ⇒ Object
Show/hide bottom pane.
-
#show_full_screen ⇒ Object
Show/hide fullscreen button.
-
#show_hidden_slides ⇒ Object
Specifies whether the generated document should include hidden slides or not.
-
#show_left_pane ⇒ Object
Show/hide left pane.
-
#show_page_border ⇒ Object
Specifies whether border around pages should be shown.
-
#show_page_stepper ⇒ Object
Show/hide page stepper.
-
#show_search ⇒ Object
Show/hide search section.
-
#show_top_pane ⇒ Object
Show/hide whole top pane.
-
#slides_layout_options ⇒ Object
Slides layouting options.
-
#start_open_left_pane ⇒ Object
Start with opened left pane.
-
#viewer_included ⇒ Object
Specifies whether the generated SWF document should include the integrated document viewer or not.
Attributes inherited from ExportOptions
#default_regular_font, #delete_embedded_binary_objects, #font_fallback_rules, #font_subst_rules, #format, #gradient_style, #skip_java_script_links
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SwfExportOptions
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from BaseObject
#_deserialize, #_to_hash, #build_from_hash, #to_body, #to_hash, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SwfExportOptions
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 122 def initialize(attributes = {}) super if attributes.has_key?(:'ShowHiddenSlides') self. = attributes[:'ShowHiddenSlides'] end if attributes.has_key?(:'Compressed') self.compressed = attributes[:'Compressed'] end if attributes.has_key?(:'ViewerIncluded') self.viewer_included = attributes[:'ViewerIncluded'] end if attributes.has_key?(:'ShowPageBorder') self.show_page_border = attributes[:'ShowPageBorder'] end if attributes.has_key?(:'ShowFullScreen') self.show_full_screen = attributes[:'ShowFullScreen'] end if attributes.has_key?(:'ShowPageStepper') self.show_page_stepper = attributes[:'ShowPageStepper'] end if attributes.has_key?(:'ShowSearch') self.show_search = attributes[:'ShowSearch'] end if attributes.has_key?(:'ShowTopPane') self.show_top_pane = attributes[:'ShowTopPane'] end if attributes.has_key?(:'ShowBottomPane') self.show_bottom_pane = attributes[:'ShowBottomPane'] end if attributes.has_key?(:'ShowLeftPane') self.show_left_pane = attributes[:'ShowLeftPane'] end if attributes.has_key?(:'StartOpenLeftPane') self.start_open_left_pane = attributes[:'StartOpenLeftPane'] end if attributes.has_key?(:'EnableContextMenu') self. = attributes[:'EnableContextMenu'] end if attributes.has_key?(:'LogoImage') self.logo_image = attributes[:'LogoImage'] end if attributes.has_key?(:'LogoLink') self.logo_link = attributes[:'LogoLink'] end if attributes.has_key?(:'JpegQuality') self.jpeg_quality = attributes[:'JpegQuality'] end if attributes.has_key?(:'SlidesLayoutOptions') self. = attributes[:'SlidesLayoutOptions'] end self.format = 'swf' end |
Instance Attribute Details
#compressed ⇒ Object
Specifies whether the generated SWF document should be compressed or not. Default is true.
32 33 34 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 32 def compressed @compressed end |
#enable_context_menu ⇒ Object
Enable/disable context menu. Default is true.
62 63 64 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 62 def @enable_context_menu end |
#jpeg_quality ⇒ Object
Specifies the quality of JPEG images. Default is 95.
71 72 73 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 71 def jpeg_quality @jpeg_quality end |
#logo_image ⇒ Object
Image that will be displayed as logo in the top right corner of the viewer. The image data is a base 64 string. Image should be 32x64 pixels PNG image, otherwise logo can be displayed improperly.
65 66 67 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 65 def logo_image @logo_image end |
#logo_link ⇒ Object
Gets or sets the full hyperlink address for a logo. Has an effect only if a LogoImage is specified.
68 69 70 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 68 def logo_link @logo_link end |
#show_bottom_pane ⇒ Object
Show/hide bottom pane. Can be overridden in flashvars. Default is true.
53 54 55 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 53 def show_bottom_pane @show_bottom_pane end |
#show_full_screen ⇒ Object
Show/hide fullscreen button. Can be overridden in flashvars. Default is true.
41 42 43 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 41 def show_full_screen @show_full_screen end |
#show_hidden_slides ⇒ Object
Specifies whether the generated document should include hidden slides or not. Default is false.
29 30 31 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 29 def @show_hidden_slides end |
#show_left_pane ⇒ Object
Show/hide left pane. Can be overridden in flashvars. Default is true.
56 57 58 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 56 def show_left_pane @show_left_pane end |
#show_page_border ⇒ Object
Specifies whether border around pages should be shown. Default is true.
38 39 40 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 38 def show_page_border @show_page_border end |
#show_page_stepper ⇒ Object
Show/hide page stepper. Can be overridden in flashvars. Default is true.
44 45 46 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 44 def show_page_stepper @show_page_stepper end |
#show_search ⇒ Object
Show/hide search section. Can be overridden in flashvars. Default is true.
47 48 49 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 47 def show_search @show_search end |
#show_top_pane ⇒ Object
Show/hide whole top pane. Can be overridden in flashvars. Default is true.
50 51 52 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 50 def show_top_pane @show_top_pane end |
#slides_layout_options ⇒ Object
Slides layouting options
74 75 76 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 74 def @slides_layout_options end |
#start_open_left_pane ⇒ Object
Start with opened left pane. Can be overridden in flashvars. Default is false.
59 60 61 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 59 def start_open_left_pane @start_open_left_pane end |
#viewer_included ⇒ Object
Specifies whether the generated SWF document should include the integrated document viewer or not. Default is true.
35 36 37 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 35 def viewer_included @viewer_included end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 77 def self.attribute_map super.merge({ :'show_hidden_slides' => :'ShowHiddenSlides', :'compressed' => :'Compressed', :'viewer_included' => :'ViewerIncluded', :'show_page_border' => :'ShowPageBorder', :'show_full_screen' => :'ShowFullScreen', :'show_page_stepper' => :'ShowPageStepper', :'show_search' => :'ShowSearch', :'show_top_pane' => :'ShowTopPane', :'show_bottom_pane' => :'ShowBottomPane', :'show_left_pane' => :'ShowLeftPane', :'start_open_left_pane' => :'StartOpenLeftPane', :'enable_context_menu' => :'EnableContextMenu', :'logo_image' => :'LogoImage', :'logo_link' => :'LogoLink', :'jpeg_quality' => :'JpegQuality', :'slides_layout_options' => :'SlidesLayoutOptions', }) end |
.swagger_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 99 def self.swagger_types super.merge({ :'show_hidden_slides' => :'BOOLEAN', :'compressed' => :'BOOLEAN', :'viewer_included' => :'BOOLEAN', :'show_page_border' => :'BOOLEAN', :'show_full_screen' => :'BOOLEAN', :'show_page_stepper' => :'BOOLEAN', :'show_search' => :'BOOLEAN', :'show_top_pane' => :'BOOLEAN', :'show_bottom_pane' => :'BOOLEAN', :'show_left_pane' => :'BOOLEAN', :'start_open_left_pane' => :'BOOLEAN', :'enable_context_menu' => :'BOOLEAN', :'logo_image' => :'String', :'logo_link' => :'String', :'jpeg_quality' => :'Integer', :'slides_layout_options' => :'SlidesLayoutOptions', }) end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && default_regular_font == o.default_regular_font && == o. && gradient_style == o.gradient_style && font_fallback_rules == o.font_fallback_rules && font_subst_rules == o.font_subst_rules && skip_java_script_links == o.skip_java_script_links && format == o.format && == o. && compressed == o.compressed && viewer_included == o.viewer_included && show_page_border == o.show_page_border && show_full_screen == o.show_full_screen && show_page_stepper == o.show_page_stepper && show_search == o.show_search && show_top_pane == o.show_top_pane && show_bottom_pane == o.show_bottom_pane && show_left_pane == o.show_left_pane && start_open_left_pane == o.start_open_left_pane && == o. && logo_image == o.logo_image && logo_link == o.logo_link && jpeg_quality == o.jpeg_quality && == o. end |
#eql?(o) ⇒ Boolean
237 238 239 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 237 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
243 244 245 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 243 def hash [default_regular_font, , gradient_style, font_fallback_rules, font_subst_rules, skip_java_script_links, format, , compressed, viewer_included, show_page_border, show_full_screen, show_page_stepper, show_search, show_top_pane, show_bottom_pane, show_left_pane, start_open_left_pane, , logo_image, logo_link, jpeg_quality, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
193 194 195 196 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 193 def list_invalid_properties invalid_properties = super invalid_properties end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
200 201 202 203 |
# File 'lib/aspose_slides_cloud/models/swf_export_options.rb', line 200 def valid? return false if !super true end |